@@ -25,8 +25,8 @@ import numpy as np
 import xarray as xr
 
 from satpy.modifiers import ModifierBase
-from satpy.modifiers._angles import get_angles, get_satellite_zenith_angle
 from satpy.modifiers._crefl import ReflectanceCorrector  # noqa
+from satpy.modifiers.angles import get_angles, get_satellite_zenith_angle
 
 logger = logging.getLogger(__name__)
 
@@ -34,7 +34,7 @@ logger = logging.getLogger(__name__)
 class PSPRayleighReflectance(ModifierBase):
     """Pyspectral-based rayleigh corrector for visible channels."""
 
-    _rayleigh_cache = WeakValueDictionary()
+    _rayleigh_cache: "WeakValueDictionary[tuple, object]" = WeakValueDictionary()
 
     def __call__(self, projectables, optional_datasets=None, **info):
         """Get the corrected reflectance when removing Rayleigh scattering.
@@ -50,11 +50,12 @@ class PSPRayleighReflectance(ModifierBase):
             vis, red, sata, satz, suna, sunz = self.match_data_arrays(
                 projectables + optional_datasets)
             sata, satz, suna, sunz = optional_datasets
-            # get the dask array underneath
-            sata = sata.data
-            satz = satz.data
-            suna = suna.data
-            sunz = sunz.data
+
+        # get the dask array underneath
+        sata = sata.data
+        satz = satz.data
+        suna = suna.data
+        sunz = sunz.data
 
         # First make sure the two azimuth angles are in the range 0-360:
         sata = sata % 360.
@@ -118,6 +119,7 @@ class PSPAtmosphericalCorrection(ModifierBase):
             satz = optional_datasets[0]
         else:
             satz = get_satellite_zenith_angle(band)
+        satz = satz.data  # get dask array underneath
 
         logger.info('Correction for limb cooling')
         corrector = AtmosphericalCorrection(band.attrs['platform_name'],
