@@ -33,22 +33,26 @@ the data was actually observed. Scheduled time can be accessed from the
 """
 
 import logging
+import os
+import warnings
 from datetime import datetime, timedelta
 
-import numpy as np
 import dask.array as da
+import numpy as np
 import xarray as xr
-import warnings
-import os
 
 from satpy import CHUNK_SIZE
-from satpy.readers.file_handlers import BaseFileHandler
-from satpy.readers.utils import unzip_file, get_geostationary_mask, \
-                                np2str, get_earth_radius, \
-                                get_user_calibration_factors, \
-                                apply_rad_correction
-from satpy.readers._geos_area import get_area_extent, get_area_definition
 from satpy._compat import cached_property
+from satpy.readers._geos_area import get_area_definition, get_area_extent
+from satpy.readers.file_handlers import BaseFileHandler
+from satpy.readers.utils import (
+    apply_rad_correction,
+    get_earth_radius,
+    get_geostationary_mask,
+    get_user_calibration_factors,
+    np2str,
+    unzip_file,
+)
 
 AHI_CHANNEL_NAMES = ("1", "2", "3", "4", "5",
                      "6", "7", "8", "9", "10",
