@@ -19,17 +19,19 @@
 """Reader for eps level 1b data. Uses xml files as a format description."""
 
 import logging
-
-import numpy as np
-import xarray as xr
+from functools import lru_cache
 
 import dask.array as da
+import numpy as np
+import xarray as xr
 from dask.delayed import delayed
 from pyresample.geometry import SwathDefinition
+
+from satpy import CHUNK_SIZE
+from satpy._compat import cached_property
 from satpy._config import get_config_path
 from satpy.readers.file_handlers import BaseFileHandler
 from satpy.readers.xmlformat import XMLFormat
-from satpy import CHUNK_SIZE
 
 logger = logging.getLogger(__name__)
 
@@ -38,12 +40,12 @@ C2 = 1.4387863  # K/cm-1
 
 
 def radiance_to_bt(arr, wc_, a__, b__):
-    """Convert to BT."""
+    """Convert to BT in K."""
     return a__ + b__ * (C2 * wc_ / (da.log(1 + (C1 * (wc_ ** 3) / arr))))
 
 
 def radiance_to_refl(arr, solar_flux):
-    """Convert to reflectances."""
+    """Convert to reflectances in %."""
     return arr * np.pi * 100.0 / solar_flux
 
 
@@ -144,10 +146,7 @@ class EPSAVHRRFile(BaseFileHandler):
         super(EPSAVHRRFile, self).__init__(
             filename, filename_info, filetype_info)
 
-        self.lons, self.lats = None, None
-        self.sun_azi, self.sun_zen, self.sat_azi, self.sat_zen = None, None, None, None
         self.area = None
-        self.three_a_mask, self.three_b_mask = None, None
         self._start_time = filename_info['start_time']
         self._end_time = filename_info['end_time']
         self.form = None
@@ -187,11 +186,9 @@ class EPSAVHRRFile(BaseFileHandler):
             keys += val.dtype.fields.keys()
         return keys
 
+    @lru_cache(maxsize=1)
     def get_full_lonlats(self):
         """Get the interpolated longitudes and latitudes."""
-        if self.lons is not None and self.lats is not None:
-            return self.lons, self.lats
-
         raw_lats = np.hstack((self["EARTH_LOCATION_FIRST"][:, [0]],
                               self["EARTH_LOCATIONS"][:, :, 0],
                               self["EARTH_LOCATION_LAST"][:, [0]]))
@@ -199,8 +196,7 @@ class EPSAVHRRFile(BaseFileHandler):
         raw_lons = np.hstack((self["EARTH_LOCATION_FIRST"][:, [1]],
                               self["EARTH_LOCATIONS"][:, :, 1],
                               self["EARTH_LOCATION_LAST"][:, [1]]))
-        self.lons, self.lats = self._interpolate(raw_lons, raw_lats)
-        return self.lons, self.lats
+        return self._interpolate(raw_lons, raw_lats)
 
     def _interpolate(self, lons_like, lats_like):
         nav_sample_rate = self["NAV_SAMPLE_RATE"]
@@ -211,11 +207,11 @@ class EPSAVHRRFile(BaseFileHandler):
             lats_like_1km = da.from_delayed(lats_like_1km, dtype=lats_like.dtype,
                                             shape=(self.scanlines, self.pixels))
             return lons_like_1km, lats_like_1km
-        else:
-            raise NotImplementedError("Lon/lat and angle expansion not implemented for " +
-                                      "sample rate = " + str(nav_sample_rate) +
-                                      " and earth views = " +
-                                      str(self.pixels))
+
+        raise NotImplementedError("Lon/lat and angle expansion not implemented for " +
+                                  "sample rate = " + str(nav_sample_rate) +
+                                  " and earth views = " +
+                                  str(self.pixels))
 
     @delayed(nout=2, pure=True)
     def _interpolate_20km_to_1km(self, lons, lats):
@@ -240,12 +236,9 @@ class EPSAVHRRFile(BaseFileHandler):
                                       " and earth views = " +
                                       str(self.pixels))
 
+    @lru_cache(maxsize=1)
     def get_full_angles(self):
         """Get the interpolated angles."""
-        if (self.sun_azi is not None and self.sun_zen is not None and
-                self.sat_azi is not None and self.sat_zen is not None):
-            return self.sun_azi, self.sun_zen, self.sat_azi, self.sat_zen
-
         solar_zenith = np.hstack((self["ANGULAR_RELATIONS_FIRST"][:, [0]],
                                   self["ANGULAR_RELATIONS"][:, :, 0],
                                   self["ANGULAR_RELATIONS_LAST"][:, [0]]))
@@ -261,11 +254,10 @@ class EPSAVHRRFile(BaseFileHandler):
                                  self["ANGULAR_RELATIONS"][:, :, 3],
                                  self["ANGULAR_RELATIONS_LAST"][:, [3]]))
 
-        self.sun_azi, self.sun_zen, self.sat_azi, self.sat_zen = self._get_full_angles(solar_zenith,
-                                                                                       sat_zenith,
-                                                                                       solar_azimuth,
-                                                                                       sat_azimuth)
-        return self.sun_azi, self.sun_zen, self.sat_azi, self.sat_zen
+        return self._get_full_angles(solar_zenith,
+                                     sat_zenith,
+                                     solar_azimuth,
+                                     sat_azimuth)
 
     def get_bounding_box(self):
         """Get bounding box."""
@@ -295,90 +287,12 @@ class EPSAVHRRFile(BaseFileHandler):
 
         elif key['name'] in ['solar_zenith_angle', 'solar_azimuth_angle',
                              'satellite_zenith_angle', 'satellite_azimuth_angle']:
-            sun_azi, sun_zen, sat_azi, sat_zen = self.get_full_angles()
-            if key['name'] == 'solar_zenith_angle':
-                dataset = create_xarray(sun_zen)
-            elif key['name'] == 'solar_azimuth_angle':
-                dataset = create_xarray(sun_azi)
-            if key['name'] == 'satellite_zenith_angle':
-                dataset = create_xarray(sat_zen)
-            elif key['name'] == 'satellite_azimuth_angle':
-                dataset = create_xarray(sat_azi)
+            dataset = self._get_angle_dataarray(key)
+        elif key['name'] in ["1", "2", "3a", "3A", "3b", "3B", "4", "5"]:
+            dataset = self._get_calibrated_dataarray(key)
         else:
-            mask = None
-            if key['calibration'] == 'counts':
-                raise ValueError('calibration=counts is not supported! ' +
-                                 'This reader cannot return counts')
-            elif key['calibration'] not in ['reflectance', 'brightness_temperature', 'radiance']:
-                raise ValueError('calibration type ' + str(key['calibration']) +
-                                 ' is not supported!')
-
-            if key['name'] in ['3A', '3a'] and self.three_a_mask is None:
-                self.three_a_mask = ((self["FRAME_INDICATOR"] & 2 ** 16) != 2 ** 16)
-
-            if key['name'] in ['3B', '3b'] and self.three_b_mask is None:
-                self.three_b_mask = ((self["FRAME_INDICATOR"] & 2 ** 16) != 0)
-
-            if key['name'] not in ["1", "2", "3a", "3A", "3b", "3B", "4", "5"]:
-                logger.info("Can't load channel in eps_l1b: " + str(key['name']))
-                return
-
-            if key['name'] == "1":
-                if key['calibration'] == 'reflectance':
-                    array = radiance_to_refl(self["SCENE_RADIANCES"][:, 0, :],
-                                             self["CH1_SOLAR_FILTERED_IRRADIANCE"])
-                else:
-                    array = self["SCENE_RADIANCES"][:, 0, :]
-
-            if key['name'] == "2":
-                if key['calibration'] == 'reflectance':
-                    array = radiance_to_refl(self["SCENE_RADIANCES"][:, 1, :],
-                                             self["CH2_SOLAR_FILTERED_IRRADIANCE"])
-                else:
-                    array = self["SCENE_RADIANCES"][:, 1, :]
-
-            if key['name'].lower() == "3a":
-                if key['calibration'] == 'reflectance':
-                    array = radiance_to_refl(self["SCENE_RADIANCES"][:, 2, :],
-                                             self["CH3A_SOLAR_FILTERED_IRRADIANCE"])
-                else:
-                    array = self["SCENE_RADIANCES"][:, 2, :]
-
-                mask = np.empty(array.shape, dtype=bool)
-                mask[:, :] = self.three_a_mask[:, np.newaxis]
-
-            if key['name'].lower() == "3b":
-                if key['calibration'] == 'brightness_temperature':
-                    array = radiance_to_bt(self["SCENE_RADIANCES"][:, 2, :],
-                                           self["CH3B_CENTRAL_WAVENUMBER"],
-                                           self["CH3B_CONSTANT1"],
-                                           self["CH3B_CONSTANT2_SLOPE"])
-                else:
-                    array = self["SCENE_RADIANCES"][:, 2, :]
-                mask = np.empty(array.shape, dtype=bool)
-                mask[:, :] = self.three_b_mask[:, np.newaxis]
-
-            if key['name'] == "4":
-                if key['calibration'] == 'brightness_temperature':
-                    array = radiance_to_bt(self["SCENE_RADIANCES"][:, 3, :],
-                                           self["CH4_CENTRAL_WAVENUMBER"],
-                                           self["CH4_CONSTANT1"],
-                                           self["CH4_CONSTANT2_SLOPE"])
-                else:
-                    array = self["SCENE_RADIANCES"][:, 3, :]
-
-            if key['name'] == "5":
-                if key['calibration'] == 'brightness_temperature':
-                    array = radiance_to_bt(self["SCENE_RADIANCES"][:, 4, :],
-                                           self["CH5_CENTRAL_WAVENUMBER"],
-                                           self["CH5_CONSTANT1"],
-                                           self["CH5_CONSTANT2_SLOPE"])
-                else:
-                    array = self["SCENE_RADIANCES"][:, 4, :]
-
-            dataset = create_xarray(array)
-            if mask is not None:
-                dataset = dataset.where(~mask)
+            logger.info("Can't load channel in eps_l1b: " + str(key['name']))
+            return
 
         dataset.attrs['platform_name'] = self.platform_name
         dataset.attrs['sensor'] = self.sensor_name
@@ -386,12 +300,68 @@ class EPSAVHRRFile(BaseFileHandler):
         dataset.attrs.update(key.to_dict())
         return dataset
 
+    def _get_angle_dataarray(self, key):
+        """Get an angle dataarray."""
+        sun_azi, sun_zen, sat_azi, sat_zen = self.get_full_angles()
+        if key['name'] == 'solar_zenith_angle':
+            dataset = create_xarray(sun_zen)
+        elif key['name'] == 'solar_azimuth_angle':
+            dataset = create_xarray(sun_azi)
+        if key['name'] == 'satellite_zenith_angle':
+            dataset = create_xarray(sat_zen)
+        elif key['name'] == 'satellite_azimuth_angle':
+            dataset = create_xarray(sat_azi)
+        return dataset
+
+    @cached_property
+    def three_a_mask(self):
+        """Mask for 3A."""
+        return (self["FRAME_INDICATOR"] & 2 ** 16) != 2 ** 16
+
+    @cached_property
+    def three_b_mask(self):
+        """Mask for 3B."""
+        return (self["FRAME_INDICATOR"] & 2 ** 16) != 0
+
+    def _get_calibrated_dataarray(self, key):
+        """Get a calibrated dataarray."""
+        if key['calibration'] not in ['reflectance', 'brightness_temperature', 'radiance']:
+            raise ValueError('calibration type ' + str(key['calibration']) +
+                             ' is not supported!')
+
+        mask = None
+
+        channel_name = key['name'].upper()
+
+        radiance_indices = {"1": 0, "2": 1, "3A": 2, "3B": 2, "4": 3, "5": 4}
+        array = self["SCENE_RADIANCES"][:, radiance_indices[channel_name], :]
+
+        if channel_name in ["1", "2", "3A"]:
+            if key['calibration'] == 'reflectance':
+                array = radiance_to_refl(array,
+                                         self[f"CH{channel_name}_SOLAR_FILTERED_IRRADIANCE"])
+            if channel_name == "3A":
+                mask = self.three_a_mask[:, np.newaxis]
+
+        if channel_name in ["3B", "4", "5"]:
+            if key['calibration'] == 'brightness_temperature':
+                array = radiance_to_bt(array,
+                                       self[f"CH{channel_name}_CENTRAL_WAVENUMBER"],
+                                       self[f"CH{channel_name}_CONSTANT1"],
+                                       self[f"CH{channel_name}_CONSTANT2_SLOPE"])
+            if channel_name == "3B":
+                mask = self.three_b_mask[:, np.newaxis]
+
+        dataset = create_xarray(array)
+        if mask is not None:
+            dataset = dataset.where(~mask)
+        return dataset
+
     def get_lonlats(self):
         """Get lonlats."""
         if self.area is None:
-            if self.lons is None or self.lats is None:
-                self.lons, self.lats = self.get_full_lonlats()
-            self.area = SwathDefinition(self.lons, self.lats)
+            lons, lats = self.get_full_lonlats()
+            self.area = SwathDefinition(lons, lats)
             self.area.name = '_'.join([self.platform_name, str(self.start_time),
                                        str(self.end_time)])
         return self.area
