@@ -479,8 +479,7 @@ def intp(grid_x, grid_y, interpolator):
 
 def interpolate_xarray_linear(xpoints, ypoints, values, shape, chunks=CHUNK_SIZE):
     """Interpolate linearly, generating a dask array."""
-    from scipy.interpolate.interpnd import (LinearNDInterpolator,
-                                            _ndim_coords_from_arrays)
+    from scipy.interpolate.interpnd import LinearNDInterpolator, _ndim_coords_from_arrays
 
     if isinstance(chunks, (list, tuple)):
         vchunks, hchunks = chunks
