@@ -27,33 +27,42 @@ References:
 
 import logging
 from datetime import datetime
-import numpy as np
 
-import xarray as xr
 import dask.array as da
-
-from satpy import CHUNK_SIZE
-
+import numpy as np
+import xarray as xr
 from pyresample import geometry
 
+from satpy import CHUNK_SIZE
 from satpy._compat import cached_property
+from satpy.readers._geos_area import get_area_definition, get_geos_area_naming
+from satpy.readers.eum_base import get_service_mode, recarray2dict, time_cds_short
 from satpy.readers.file_handlers import BaseFileHandler
-from satpy.readers.eum_base import (
-    recarray2dict, get_service_mode, time_cds_short
-)
 from satpy.readers.seviri_base import (
-    SEVIRICalibrationHandler, CHANNEL_NAMES, SATNUM, dec10216,
-    VISIR_NUM_COLUMNS, VISIR_NUM_LINES, HRV_NUM_COLUMNS, HRV_NUM_LINES,
-    create_coef_dict, pad_data_horizontally, pad_data_vertically,
-    add_scanline_acq_time, get_cds_time, OrbitPolynomialFinder, get_satpos,
-    NoValidOrbitParams
+    CHANNEL_NAMES,
+    HRV_NUM_COLUMNS,
+    HRV_NUM_LINES,
+    SATNUM,
+    VISIR_NUM_COLUMNS,
+    VISIR_NUM_LINES,
+    NoValidOrbitParams,
+    OrbitPolynomialFinder,
+    SEVIRICalibrationHandler,
+    add_scanline_acq_time,
+    create_coef_dict,
+    dec10216,
+    get_cds_time,
+    get_satpos,
+    pad_data_horizontally,
+    pad_data_vertically,
 )
 from satpy.readers.seviri_l1b_native_hdr import (
-    GSDTRecords, get_native_header, native_trailer,
-    DEFAULT_15_SECONDARY_PRODUCT_HEADER
+    DEFAULT_15_SECONDARY_PRODUCT_HEADER,
+    GSDTRecords,
+    get_native_header,
+    native_trailer,
 )
 from satpy.readers.utils import reduce_mda
-from satpy.readers._geos_area import get_area_definition, get_geos_area_naming
 
 logger = logging.getLogger('native_msg')
 
