@@ -141,19 +141,20 @@ defined.
 import hashlib
 import json
 import os
+import warnings
 from logging import getLogger
 from weakref import WeakValueDictionary
-import warnings
-import numpy as np
-import xarray as xr
+
 import dask
 import dask.array as da
-import zarr
+import numpy as np
 import pyresample
+import xarray as xr
+import zarr
 from packaging import version
-
 from pyresample.ewa import fornav, ll2cr
 from pyresample.geometry import SwathDefinition
+
 try:
     from pyresample.resampler import BaseResampler as PRBaseResampler
 except ImportError:
@@ -170,7 +171,6 @@ except ImportError:
 from satpy import CHUNK_SIZE
 from satpy._config import config_search_paths, get_config_path
 
-
 LOG = getLogger(__name__)
 
 CACHE_SIZE = 10
@@ -185,7 +185,7 @@ BIL_COORDINATES = {'bilinear_s': ('x1', ),
                    'out_coords_x': ('x2', ),
                    'out_coords_y': ('y2', )}
 
-resamplers_cache = WeakValueDictionary()
+resamplers_cache: "WeakValueDictionary[tuple, object]" = WeakValueDictionary()
 
 PR_USE_SKIPNA = version.parse(pyresample.__version__) > version.parse("1.17.0")
 
@@ -242,14 +242,12 @@ def add_xy_coords(data_arr, area, crs=None):
     if 'x' in data_arr.coords and 'y' in data_arr.coords:
         # x/y coords already provided
         return data_arr
-    elif 'x' not in data_arr.dims or 'y' not in data_arr.dims:
+    if 'x' not in data_arr.dims or 'y' not in data_arr.dims:
         # no defined x and y dimensions
         return data_arr
-
-    if hasattr(area, 'get_proj_vectors'):
-        x, y = area.get_proj_vectors()
-    else:
+    if not hasattr(area, 'get_proj_vectors'):
         return data_arr
+    x, y = area.get_proj_vectors()
 
     # convert to DataArrays
     y_attrs = {}
@@ -440,12 +438,10 @@ class BaseResampler(object):
         cache_id = self.precompute(cache_dir=cache_dir, **kwargs)
         return self.compute(data, cache_id=cache_id, **kwargs)
 
-    def _create_cache_filename(self, cache_dir=None, prefix='',
+    def _create_cache_filename(self, cache_dir, prefix='',
                                fmt='.zarr', **kwargs):
         """Create filename for the cached resampling parameters."""
-        cache_dir = cache_dir or '.'
         hash_str = self.get_hash(**kwargs)
-
         return os.path.join(cache_dir, prefix + hash_str + fmt)
 
 
@@ -495,18 +491,7 @@ class KDTreeResampler(BaseResampler):
             cache_dir = None
 
         if radius_of_influence is None and not hasattr(self.source_geo_def, 'geocentric_resolution'):
-            warnings.warn("Upgrade 'pyresample' for a more accurate default 'radius_of_influence'.")
-            try:
-                radius_of_influence = self.source_geo_def.lons.resolution * 3
-            except AttributeError:
-                try:
-                    radius_of_influence = max(abs(self.source_geo_def.pixel_size_x),
-                                              abs(self.source_geo_def.pixel_size_y)) * 3
-                except AttributeError:
-                    radius_of_influence = 1000
-
-            except TypeError:
-                radius_of_influence = 10000
+            radius_of_influence = self._adjust_radius_of_influence(radius_of_influence)
 
         kwargs = dict(source_geo_def=self.source_geo_def,
                       target_geo_def=self.target_geo_def,
@@ -526,6 +511,22 @@ class KDTreeResampler(BaseResampler):
             self.resampler.get_neighbour_info(mask=mask)
             self.save_neighbour_info(cache_dir, mask=mask, **kwargs)
 
+    def _adjust_radius_of_influence(self, radius_of_influence):
+        """Adjust radius of influence."""
+        warnings.warn("Upgrade 'pyresample' for a more accurate default 'radius_of_influence'.")
+        try:
+            radius_of_influence = self.source_geo_def.lons.resolution * 3
+        except AttributeError:
+            try:
+                radius_of_influence = max(abs(self.source_geo_def.pixel_size_x),
+                                          abs(self.source_geo_def.pixel_size_y)) * 3
+            except AttributeError:
+                radius_of_influence = 1000
+
+        except TypeError:
+            radius_of_influence = 10000
+        return radius_of_influence
+
     def _apply_cached_index(self, val, idx_name, persist=False):
         """Reassign resampler index attributes."""
         if isinstance(val, np.ndarray):
@@ -538,6 +539,8 @@ class KDTreeResampler(BaseResampler):
     def _check_numpy_cache(self, cache_dir, mask=None,
                            **kwargs):
         """Check if there's Numpy cache file and convert it to zarr."""
+        if cache_dir is None:
+            return
         fname_np = self._create_cache_filename(cache_dir,
                                                prefix='resample_lut-',
                                                mask=mask, fmt='.npz',
@@ -566,14 +569,15 @@ class KDTreeResampler(BaseResampler):
         cached = {}
         self._check_numpy_cache(cache_dir, mask=mask_name, **kwargs)
 
-        filename = self._create_cache_filename(cache_dir, prefix='nn_lut-',
-                                               mask=mask_name, **kwargs)
         for idx_name in NN_COORDINATES:
             if mask_name in self._index_caches:
                 cached[idx_name] = self._apply_cached_index(
                     self._index_caches[mask_name][idx_name], idx_name)
             elif cache_dir:
                 try:
+                    filename = self._create_cache_filename(
+                        cache_dir, prefix='nn_lut-',
+                        mask=mask_name, **kwargs)
                     fid = zarr.open(filename, 'r')
                     cache = np.array(fid[idx_name])
                     if idx_name == 'valid_input_index':
@@ -996,7 +1000,7 @@ class NativeResampler(BaseResampler):
             d_arr = da.from_array(d_arr, chunks=CHUNK_SIZE)
         if all(x == 1 for x in repeats.values()):
             return d_arr
-        elif all(x >= 1 for x in repeats.values()):
+        if all(x >= 1 for x in repeats.values()):
             # rechunk so new chunks are the same size as old chunks
             c_size = max(x[0] for x in d_arr.chunks)
 
@@ -1015,14 +1019,13 @@ class NativeResampler(BaseResampler):
                     raise ValueError("Expand factor must be a whole number")
                 d_arr = da.repeat(d_arr, int(factor), axis=axis)
             return d_arr
-        elif all(x <= 1 for x in repeats.values()):
+        if all(x <= 1 for x in repeats.values()):
             # reduce
             y_size = 1. / repeats[0]
             x_size = 1. / repeats[1]
             return cls.aggregate(d_arr, y_size, x_size)
-        else:
-            raise ValueError("Must either expand or reduce in both "
-                             "directions")
+        raise ValueError("Must either expand or reduce in both "
+                         "directions")
 
     def compute(self, data, expand=True, **kwargs):
         """Resample data with NativeResampler."""
@@ -1315,7 +1318,7 @@ def prepare_resampler(source_area, destination_area, resampler=None, **resample_
     if isinstance(resampler, (BaseResampler, PRBaseResampler)):
         raise ValueError("Trying to create a resampler when one already "
                          "exists.")
-    elif isinstance(resampler, str):
+    if isinstance(resampler, str):
         resampler_class = RESAMPLERS.get(resampler, None)
         if resampler_class is None:
             if resampler == "gradient_search":
