@@ -25,17 +25,17 @@ class TestVIIRSComposites(unittest.TestCase):
 
     def test_load_composite_yaml(self):
         """Test loading the yaml for this sensor."""
-        from satpy.composites.config_loader import CompositorLoader
-        cl = CompositorLoader()
-        cl.load_sensor_composites('viirs')
+        from satpy.composites.config_loader import load_compositor_configs_for_sensors
+        load_compositor_configs_for_sensors(['viirs'])
 
     def test_histogram_dnb(self):
         """Test the 'histogram_dnb' compositor."""
-        import xarray as xr
         import dask.array as da
         import numpy as np
-        from satpy.composites.viirs import HistogramDNB
+        import xarray as xr
         from pyresample.geometry import AreaDefinition
+
+        from satpy.composites.viirs import HistogramDNB
         rows = 5
         cols = 10
         area = AreaDefinition(
@@ -75,11 +75,12 @@ class TestVIIRSComposites(unittest.TestCase):
 
     def test_adaptive_dnb(self):
         """Test the 'adaptive_dnb' compositor."""
-        import xarray as xr
         import dask.array as da
         import numpy as np
-        from satpy.composites.viirs import AdaptiveDNB
+        import xarray as xr
         from pyresample.geometry import AreaDefinition
+
+        from satpy.composites.viirs import AdaptiveDNB
         rows = 5
         cols = 10
         area = AreaDefinition(
@@ -117,11 +118,12 @@ class TestVIIRSComposites(unittest.TestCase):
 
     def test_erf_dnb(self):
         """Test the 'dynamic_dnb' or ERF DNB compositor."""
-        import xarray as xr
         import dask.array as da
         import numpy as np
-        from satpy.composites.viirs import ERFDNB
+        import xarray as xr
         from pyresample.geometry import AreaDefinition
+
+        from satpy.composites.viirs import ERFDNB
         rows = 5
         cols = 10
         area = AreaDefinition(
@@ -171,11 +173,12 @@ class TestVIIRSComposites(unittest.TestCase):
 
     def test_hncc_dnb(self):
         """Test the 'hncc_dnb' compositor."""
-        import xarray as xr
         import dask.array as da
         import numpy as np
-        from satpy.composites.viirs import NCCZinke
+        import xarray as xr
         from pyresample.geometry import AreaDefinition
+
+        from satpy.composites.viirs import NCCZinke
         rows = 5
         cols = 10
         area = AreaDefinition(
