@@ -19,9 +19,10 @@
 import os
 import unittest
 
-import xarray as xr
 import dask.array as da
 import numpy as np
+import xarray as xr
+
 from satpy.tests.utils import make_dataid
 
 
@@ -34,6 +35,7 @@ class TestGenericImage(unittest.TestCase):
         from datetime import datetime
 
         from pyresample.geometry import AreaDefinition
+
         from satpy.scene import Scene
 
         self.date = datetime(2018, 1, 1)
@@ -132,9 +134,9 @@ class TestGenericImage(unittest.TestCase):
         scn = Scene(reader='generic_image', filenames=[fname])
         scn.load(['image'])
         self.assertEqual(scn['image'].shape, (1, self.y_size, self.x_size))
-        self.assertEqual(scn.attrs['sensor'], set(['images']))
-        self.assertEqual(scn.attrs['start_time'], None)
-        self.assertEqual(scn.attrs['end_time'], None)
+        self.assertEqual(scn.sensor_names, {'images'})
+        self.assertEqual(scn.start_time, None)
+        self.assertEqual(scn.end_time, None)
         self.assertNotIn('area', scn['image'].attrs)
 
         fname = os.path.join(self.base_dir, '20180101_0000_test_la.png')
@@ -142,9 +144,9 @@ class TestGenericImage(unittest.TestCase):
         scn.load(['image'])
         data = da.compute(scn['image'].data)
         self.assertEqual(scn['image'].shape, (1, self.y_size, self.x_size))
-        self.assertEqual(scn.attrs['sensor'], set(['images']))
-        self.assertEqual(scn.attrs['start_time'], self.date)
-        self.assertEqual(scn.attrs['end_time'], self.date)
+        self.assertEqual(scn.sensor_names, {'images'})
+        self.assertEqual(scn.start_time, self.date)
+        self.assertEqual(scn.end_time, self.date)
         self.assertNotIn('area', scn['image'].attrs)
         self.assertEqual(np.sum(np.isnan(data)), 100)
 
@@ -156,18 +158,18 @@ class TestGenericImage(unittest.TestCase):
         scn = Scene(reader='generic_image', filenames=[fname])
         scn.load(['image'])
         self.assertEqual(scn['image'].shape, (3, self.y_size, self.x_size))
-        self.assertEqual(scn.attrs['sensor'], set(['images']))
-        self.assertEqual(scn.attrs['start_time'], self.date)
-        self.assertEqual(scn.attrs['end_time'], self.date)
+        self.assertEqual(scn.sensor_names, {'images'})
+        self.assertEqual(scn.start_time, self.date)
+        self.assertEqual(scn.end_time, self.date)
         self.assertEqual(scn['image'].area, self.area_def)
 
         fname = os.path.join(self.base_dir, 'test_rgba.tif')
         scn = Scene(reader='generic_image', filenames=[fname])
         scn.load(['image'])
         self.assertEqual(scn['image'].shape, (3, self.y_size, self.x_size))
-        self.assertEqual(scn.attrs['sensor'], set(['images']))
-        self.assertEqual(scn.attrs['start_time'], None)
-        self.assertEqual(scn.attrs['end_time'], None)
+        self.assertEqual(scn.sensor_names, {'images'})
+        self.assertEqual(scn.start_time, None)
+        self.assertEqual(scn.end_time, None)
         self.assertEqual(scn['image'].area, self.area_def)
 
     def test_geotiff_scene_nan(self):
