@@ -24,12 +24,12 @@ import unittest
 import warnings
 from unittest import mock
 
-import pytest
-import numpy as np
-import xarray as xr
 import dask.array as da
+import numpy as np
+import pytest
+import xarray as xr
 
-from satpy.utils import angle2xyz, lonlat2xyz, xyz2angle, xyz2lonlat, proj_units_to_meters, get_satpos
+from satpy.utils import angle2xyz, get_satpos, lonlat2xyz, proj_units_to_meters, xyz2angle, xyz2lonlat
 
 
 class TestUtils(unittest.TestCase):
@@ -317,7 +317,7 @@ class TestCheckSatpy(unittest.TestCase):
 
 def test_debug_on(caplog):
     """Test that debug_on is working as expected."""
-    from satpy.utils import debug_on, debug_off, debug
+    from satpy.utils import debug, debug_off, debug_on
 
     def depwarn():
         logger = logging.getLogger("satpy.silly")
@@ -346,7 +346,7 @@ def test_debug_on(caplog):
 
 def test_logging_on_and_off(caplog):
     """Test that switching logging on and off works."""
-    from satpy.utils import logging_on, logging_off
+    from satpy.utils import logging_off, logging_on
     logger = logging.getLogger("satpy.silly")
     logging_on()
     with caplog.at_level(logging.WARNING):
@@ -394,23 +394,23 @@ def test_unify_chunks(shapes, chunks, dims, exp_unified):
         _verify_unchanged_chunks(results, inputs)
 
 
-def _data_arrays_from_params(shapes: list[tuple[int, ...], ...],
-                             chunks: list[tuple[int, ...], ...],
-                             dims: list[tuple[int, ...], ...]
+def _data_arrays_from_params(shapes: list[tuple[int, ...]],
+                             chunks: list[tuple[int, ...]],
+                             dims: list[tuple[int, ...]]
                              ) -> typing.Generator[xr.DataArray, None, None]:
     for shape, chunk, dim in zip(shapes, chunks, dims):
         yield xr.DataArray(da.ones(shape, chunks=chunk), dims=dim)
 
 
-def _verify_unified(data_arrays: list[xr.DataArray, ...]) -> None:
-    dim_chunks = {}
+def _verify_unified(data_arrays: list[xr.DataArray]) -> None:
+    dim_chunks: dict[str, int] = {}
     for data_arr in data_arrays:
         for dim, chunk_size in zip(data_arr.dims, data_arr.chunks):
             exp_chunks = dim_chunks.setdefault(dim, chunk_size)
             assert exp_chunks == chunk_size
 
 
-def _verify_unchanged_chunks(data_arrays: list[xr.DataArray, ...],
-                             orig_arrays: list[xr.DataArray, ...]) -> None:
+def _verify_unchanged_chunks(data_arrays: list[xr.DataArray],
+                             orig_arrays: list[xr.DataArray]) -> None:
     for data_arr, orig_arr in zip(data_arrays, orig_arrays):
         assert data_arr.chunks == orig_arr.chunks
